<?php
/**
 * 移动端付款返回页，仅用于微信支付移动浏览器
 * 该控制器是为了修复微信缺陷，如果直接返回系统默认的返回页，可能出现已付款而提示没有付款的情况，需要用户自行刷新确认
 *
 * Company: 未来很美（深圳）科技有限公司 site: www.will-nice.com
 * Developer: 云客【云游天下，做客四方】 site: www.indrupal.com
 * 微信号：indrupal
 * Email：phpworld@qq.com
 */

namespace Drupal\commerce_wechat\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Url;


class ReturnPage extends ControllerBase {

  /**
   * 显示付款返回页
   *
   * @param $orderID    string 订单ID
   * @param $paymentID  string 支付ID
   *
   * @return array 响应渲染数组
   */
  public function index($orderID, $paymentID) {
    $page = [];
    $page['waitMsg'] = [
      '#type'       => 'html_tag',
      '#tag'        => 'div',
      '#value'      => $this->t('Payment processing... Please wait'),//当付款返回后显示“付款处理中...请稍后”  然后判断条件进行自动跳转
      '#attributes' => [
        'id' => 'commerce-wechat-return-page-wait-msg',//提供页面定位
      ],
    ];
    $page['successMsg'] = [
      '#type'       => 'html_tag',
      '#tag'        => 'div',
      '#value'      => $this->t('Payment successful'),
      '#attributes' => [
        'style' => 'display:none;', //供前端付款成功时显示
        'id'    => 'commerce-wechat-return-page-success-msg',//提供页面定位
      ],
    ];

    $checkURL = Url::fromRoute('commerce_wechat.paymentCheck', ['paymentID' => $paymentID])->toString();
    //通过JS变量传递机制，为自动跳转传递付款核验链接 值如“/commerce-wechat/payments/check/53”
    $page['#attached']['drupalSettings']['checkURL'] = $checkURL;


    $defaultReturnURL = Url::fromRoute('commerce_payment.checkout.return', [
      'commerce_order' => $orderID,
      'step'           => 'payment',
    ], [
      //'absolute' => TRUE, //此处无需绝对链接
      'query'      => ['payment' => $paymentID],
      'attributes' => ['class' => ['button'], 'id' => 'commerce-wechat-return-page-url'],
    ]);//默认的系统返回链接

    $page['returnLink'] = [
      '#type'  => 'link',
      '#title' => $this->t('Return'),
      '#url'   => $defaultReturnURL,
    ];
    $page['#attached']['library'][] = 'commerce_wechat/commerce_wechat.returnPage'; //该库用于判断是否已经付款，自动跳转页面
    return $page;
  }


}
